# CricCatapult

#### A novel cricket data package with a focus on data visualization, easily accessible data, and data analysis

Packaging: https://pypi.org/project/criccatapult/0.0.5/

### To run/test out this package, simply clone the project and run it locally.
### Alternatively run
```
pip3 install CricCatapult==0.0.5
```

Due to API problems, the geography classes (Location, etc.) do not work with the current packaging. However, the rest of the classes are bug-free.


### Documentation
https://criccatapult.readthedocs.io/en/latest/

### Submitted to CMSAC 2022
